.. image:: https://github.com/MarcoGorelli/nbQA/raw/master/assets/logo.png
  :width: 400

nbQA
====

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   modules
   contributing
   authors

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
